@@ -18,14 +18,16 @@
 #'                        territorial units considered. In general, The sum by rows of `votes_election1` and
 #'                        `votes_election2` must coincide.
 #'
-#' @param counts A TRUE/FALSE value that indicates whether the problem is solved in integer values (counts),
-#'               in both iterations: zero (lphom) and final (including unit) solutions. If TRUE, the LP matrices
-#'               are approximated to the closest integer solution solving the corresponding Integer Linear Program.
-#'               Default, FALSE.
+#' @param integers A TRUE/FALSE value that indicates whether the problem is solved in integer values
+#'                 in both iterations: zero (lphom) and final (including unit) solutions. If TRUE, the LP matrices
+#'                 are approximated to the closest integer solution solving the corresponding Integer Linear Program.
+#'                 Default, FALSE.
 #'
 #' @param solver A character string indicating the linear programming solver to be used, only
 #'               `lp_solve` and `symphony` are allowed. By default, `lp_solve`.
 #'
+#' @param ... Other arguments to be passed to the function. Not currently used.
+#'
 #' @return
 #' A list with the following components
 #'  \item{VTM.votes.w}{ The matrix of order JxK with the estimated cross-distribution of votes of elections 1 and 2,
@@ -72,16 +74,20 @@
 
 tslphom_dual <- function(votes_election1,
                          votes_election2,
-                         counts = FALSE,
-                         solver = "lp_solve"){
-
+                         integers = FALSE,
+                         solver = "lp_solve",
+                         ...){
+  
+  argg <- c(as.list(environment()), list(...))
+  integers <- test_integers(argg)
+  
   inputs <- list("votes_election1" = votes_election1, "votes_election2" = votes_election2,
-                 "counts" = counts, "solver" = solver)
+                 "integers" = integers, "solver" = solver)
 
   lphom.object.12 <- tslphom(votes_election1, votes_election2, "simultaneous",
-                           counts = counts, solver = solver)
+                           integers = integers, solver = solver)
   lphom.object.21 <- tslphom(votes_election2, votes_election1, "simultaneous",
-                           counts = counts, solver = solver)
+                           integers = integers, solver = solver)
 
   votos.units.a <- (lphom.object.12$VTM.votes.units +
                       aperm(lphom.object.21$VTM.votes.units, c(2, 1, 3)))/2
@@ -89,7 +95,7 @@ tslphom_dual <- function(votes_election1,
                       aperm(lphom.object.21$VTM.votes.units, c(2, 1, 3))*lphom.object.21$HETe^-1)/
     (lphom.object.12$HETe^-1 + lphom.object.21$HETe^-1)
 
-  if (counts){
+  if (integers){
     for (i in 1L:nrow(lphom.object.12$origin)){
       votos.units.a[, , i] <- dec2counts(votos.units.a[, , i],
                                          lphom.object.12$origin[i,],
